==> haskell-hslua-classes-2.3.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-ymhcA4L0BZ2ks28ctk7jD
key:                  hslua-classes-2.3.0-ymhcA4L0BZ2ks28ctk7jD
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  abaa8d0e71e83b6515b93b45e4258e8d
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-ymhcA4L0BZ2ks28ctk7jD
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-4bnBEvyBsJcD7HXoSCZZdG
    hslua-marshalling-2.3.1-Dsoe6PinhJy561l70lQCyV text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-classes-2.3.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-classes
version:              2.3.0
visibility:           public
id:                   hslua-classes-2.3.0-7ttrYPKrfzvK4MEwCOmdvm
key:                  hslua-classes-2.3.0-7ttrYPKrfzvK4MEwCOmdvm
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  b12a31f18634a41bca2fc7584a309e72
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-classes-2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-classes-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.0-7ttrYPKrfzvK4MEwCOmdvm
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    exceptions-0.10.4 hslua-core-2.3.1-1AmI8zGzjZL1RLIxXelUsx
    hslua-marshalling-2.3.1-GoTqmJns27o7rM7C5G4nSE text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
